# (WIP) Stamp Processing
 > A package develop by Sun* AI Research Team as part of the PDF Converter project. 

 This is a package for detecting and removing stamp from document images.
 This package uses  [Yolov5](https://github.com/ultralytics/yolov5) for the stamp detection model and [fastai](https://github.com/fastai/fastai) for stamp removal model

 ## Install
 To install the package, use `pip`:
 `pip install stamp_processing`

 ## How to use
 Check out the `getting_started.ipynb` in the `example` folder for example usage

 ## Contact 
 Create an issue if you run into any issue or contact us at [sun.converter.team@gmail.com](sun.converter.team@gmail.com)